Cloud workflows - multi-step operations
These workflows compose Layer 1 operations with progress tracking and additional logic.
Functions
- backup_
database_ and_ wait - Backup a database and wait for completion
- create_
database_ and_ wait - Create a database and wait for completion
- create_
subscription_ and_ wait - Create a subscription and wait for completion
- delete_
database_ and_ wait - Delete a database and wait for completion
- delete_
subscription_ and_ wait - Delete a subscription and wait for completion
- flush_
database_ and_ wait - Flush all data from a database and wait for completion
- import_
database_ and_ wait - Import data into a database and wait for completion
- update_
database_ and_ wait - Update a database and wait for completion
- update_
subscription_ and_ wait - Update a subscription and wait for completion