Module config

Module config 

Configuration and profile management for Redis CLI tools

This module provides a reusable configuration system for managing credentials and settings for Redis Cloud and Redis Enterprise deployments.

Features

  • Multiple named profiles for different Redis deployments
  • Secure credential storage using OS keyring (optional)
  • Environment variable expansion in config files
  • Platform-specific config file locations
  • Support for both Redis Cloud and Redis Enterprise

Re-exports

pub use config::Config;
pub use config::DeploymentType;
pub use config::Profile;
pub use config::ProfileCredentials;
pub use credential::CredentialStorage;
pub use credential::CredentialStore;
pub use error::ConfigError;
pub use error::Result;
pub use resilience::ResilienceConfig;

Modules

config
Configuration management for Redis CLI tools
credential
Credential storage abstraction with optional keyring support
error
Error types for configuration operations
resilience
Resilience configuration for API clients