Module workflows

Module workflows 

Cloud workflows - multi-step operations

These workflows compose Layer 1 operations with progress tracking and additional logic.

Functions

backup_database_and_wait
Backup a database and wait for completion
create_database_and_wait
Create a database and wait for completion
create_subscription_and_wait
Create a subscription and wait for completion
delete_database_and_wait
Delete a database and wait for completion
delete_subscription_and_wait
Delete a subscription and wait for completion
flush_database_and_wait
Flush all data from a database and wait for completion
import_database_and_wait
Import data into a database and wait for completion
update_database_and_wait
Update a database and wait for completion
update_subscription_and_wait
Update a subscription and wait for completion