Progress tracking and action polling for async Enterprise operations
Enterprise API operations that are asynchronous return an Action which must be polled
until completion. This module provides utilities for that polling
with optional progress callbacks for UI updates.
Enums
- Enterprise
Progress Event - Progress events emitted during async Enterprise operations
Functions
- poll_
action - Poll an Enterprise action until completion
Type Aliases
- Enterprise
Progress Callback - Callback type for Enterprise progress updates